@@ -1,7 +1,7 @@
 // cl_immediate_classes.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/object.h"
