@@ -55,38 +55,38 @@ uninitialized_exception::uninitialized_exception (const _cl_ring_element& obj_x,
 
 static const _cl_ring_element dummy_op0 (cl_heap_ring* R)
 {
-	unused R;
+	cl_unused R;
 	throw uninitialized_ring_exception();
 }
 
 static const _cl_ring_element dummy_op1 (cl_heap_ring* R, const _cl_ring_element& x)
 {
-	unused R;
+	cl_unused R;
 	throw uninitialized_exception(x);
 }
 
 static const _cl_ring_element dummy_op2 (cl_heap_ring* R, const _cl_ring_element& x, const _cl_ring_element& y)
 {
-	unused R;
+	cl_unused R;
 	throw uninitialized_exception(x, y);
 }
 
 static void dummy_fprint (cl_heap_ring* R, std::ostream& stream, const _cl_ring_element& x)
 {
-	unused R;
-	unused stream;
+	cl_unused R;
+	cl_unused stream;
 	throw uninitialized_exception(x);
 }
 static bool dummy_equal (cl_heap_ring* R, const _cl_ring_element& x, const _cl_ring_element& y)
 {
-	unused R;
+	cl_unused R;
 	throw uninitialized_exception(x, y);
 }
 
 #define dummy_zero dummy_op0
 static bool dummy_zerop (cl_heap_ring* R, const _cl_ring_element& x)
 {
-	unused R;
+	cl_unused R;
 	throw uninitialized_exception(x);
 }
 #define dummy_plus dummy_op2
@@ -96,7 +96,7 @@ static bool dummy_zerop (cl_heap_ring* R, const _cl_ring_element& x)
 #define dummy_one dummy_op0
 static const _cl_ring_element dummy_canonhom (cl_heap_ring* R, const cl_I& x)
 {
-	unused R;
+	cl_unused R;
 	(void)&x; // unused x;
 	throw uninitialized_ring_exception();
 }
@@ -104,7 +104,7 @@ static const _cl_ring_element dummy_canonhom (cl_heap_ring* R, const cl_I& x)
 #define dummy_square dummy_op1
 static const _cl_ring_element dummy_expt_pos (cl_heap_ring* R, const _cl_ring_element& x, const cl_I& y)
 {
-	unused R;
+	cl_unused R;
 	(void)&y; // unused y;
 	throw uninitialized_exception(x);
 }
@@ -146,7 +146,7 @@ static void cl_no_ring_destructor (cl_heap* pointer)
 
 static void cl_no_ring_dprint (cl_heap* pointer)
 {
-	unused pointer;
+	cl_unused pointer;
 	fprint(cl_debugout, "(cl_ring) cl_no_ring");
 }
 
