@@ -1,18 +1,18 @@
 // cl_LF_to_FF().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_F.h"
+#include "float/cl_F.h"
 
 
 // Implementation.
 
-#include "cl_LF.h"
-#include "cl_LF_impl.h"
-#include "cl_FF.h"
-#include "cl_DS.h"
+#include "float/lfloat/cl_LF.h"
+#include "float/lfloat/cl_LF_impl.h"
+#include "float/ffloat/cl_FF.h"
+#include "base/digitseq/cl_DS.h"
 
 namespace cln {
 
@@ -20,7 +20,7 @@ const cl_FF cl_LF_to_FF (const cl_LF& x)
 {
 	// x entpacken:
 	var cl_signean sign;
-	var sintL exp;
+	var sintE exp;
 	var uintD* ptr;
 	var uintC len;
 	LF_decode(x, { return cl_FF_0; }, sign=,exp=,ptr=,len=,);
@@ -46,7 +46,7 @@ const cl_FF cl_LF_to_FF (const cl_LF& x)
 	  { mant = mant >> shiftcount;
 	    mant = mant+1;
 	    if (mant >= bit(FF_mant_len+1))
-	      // berlauf durchs Runden
+	      // Überlauf durchs Runden
 	      { mant = mant>>1; exp = exp+1; } // Mantisse rechts schieben
 	  }
 	return encode_FF(sign,exp,mant);
