@@ -1,7 +1,7 @@
 // truncate2().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/float.h"
@@ -9,15 +9,15 @@
 
 // Implementation.
 
-#include "cl_F.h"
+#include "float/cl_F.h"
 #include "cln/sfloat.h"
 #include "cln/ffloat.h"
 #include "cln/dfloat.h"
 #include "cln/lfloat.h"
-#include "cl_SF.h"
-#include "cl_FF.h"
-#include "cl_DF.h"
-#include "cl_LF.h"
+#include "float/sfloat/cl_SF.h"
+#include "float/ffloat/cl_FF.h"
+#include "float/dfloat/cl_DF.h"
+#include "float/lfloat/cl_LF.h"
 
 namespace cln {
 
