@@ -1,7 +1,7 @@
 // float_precision().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/ffloat.h"
@@ -9,10 +9,10 @@
 
 // Implementation.
 
-#include "cl_FF.h"
+#include "float/ffloat/cl_FF.h"
 
-#include "cl_inline.h"
-#include "cl_FF_zerop.cc"
+#include "base/cl_inline.h"
+#include "float/ffloat/elem/cl_FF_zerop.cc"
 
 namespace cln {
 
