@@ -24,8 +24,8 @@ const cl_LF cl_LF_RA_div (const cl_LF& x, const cl_RA& y)
 		return cl_LF_I_div(x,y);
 	} else {
 		DeclareType(cl_RT,y);
-		var const cl_I& u = TheRatio(y)->numerator; // u /= 0
-		var const cl_I& v = TheRatio(y)->denominator; // v /= 0
+		var const cl_I& u = numerator(y); // u /= 0
+		var const cl_I& v = denominator(y); // v /= 0
 		return cl_LF_I_div(The(cl_LF)(cl_LF_I_mul(x,v)),u);
 	}
 }
