@@ -1,7 +1,7 @@
 // decode_float().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/float.h"
@@ -9,17 +9,17 @@
 
 // Implementation.
 
-#include "cl_SF.h"
-#include "cl_FF.h"
-#include "cl_DF.h"
-#include "cl_LF.h"
-#include "cl_LF_impl.h"
-#include "cl_I.h"
-#include "cl_F.h"
+#include "float/sfloat/cl_SF.h"
+#include "float/ffloat/cl_FF.h"
+#include "float/dfloat/cl_DF.h"
+#include "float/lfloat/cl_LF.h"
+#include "float/lfloat/cl_LF_impl.h"
+#include "integer/cl_I.h"
+#include "float/cl_F.h"
 
 namespace cln {
 
-inline const decoded_float decode_float (const cl_SF& x)
+static inline const decoded_float decode_float_inline (const cl_SF& x)
 {
 	// x entpacken:
 	var cl_signean sign;
@@ -35,7 +35,7 @@ inline const decoded_float decode_float (const cl_SF& x)
 	       );
 }
 
-inline const decoded_float decode_float (const cl_FF& x)
+static inline const decoded_float decode_float_inline (const cl_FF& x)
 {
 	// x entpacken:
 	var cl_signean sign;
@@ -51,7 +51,7 @@ inline const decoded_float decode_float (const cl_FF& x)
 	       );
 }
 
-inline const decoded_float decode_float (const cl_DF& x)
+static inline const decoded_float decode_float_inline (const cl_DF& x)
 {
 	// x entpacken:
 	var cl_signean sign;
@@ -80,7 +80,7 @@ inline const decoded_float decode_float (const cl_DF& x)
 #endif
 }
 
-inline const decoded_float decode_float (const cl_LF& x)
+static inline const decoded_float decode_float_inline (const cl_LF& x)
 {
 	// x entpacken:
 	var cl_signean sign;
@@ -99,10 +99,10 @@ inline const decoded_float decode_float (const cl_LF& x)
 const decoded_float decode_float (const cl_F& x)
 {
 	floatcase(x
-	,	return decode_float(x);
-	,	return decode_float(x);
-	,	return decode_float(x);
-	,	return decode_float(x);
+	,	return decode_float_inline(x);
+	,	return decode_float_inline(x);
+	,	return decode_float_inline(x);
+	,	return decode_float_inline(x);
 	);
 }
 
