@@ -1,7 +1,7 @@
 // scale_float().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/sfloat.h"
@@ -9,8 +9,8 @@
 
 // Implementation.
 
-#include "cl_SF.h"
-#include "cl_F.h"
+#include "float/sfloat/cl_SF.h"
+#include "float/cl_F.h"
 
 namespace cln {
 
