@@ -1,7 +1,7 @@
 // float_exponent().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/sfloat.h"
@@ -9,7 +9,7 @@
 
 // Implementation.
 
-#include "cl_SF.h"
+#include "float/sfloat/cl_SF.h"
 
 namespace cln {
 
