@@ -1,7 +1,7 @@
 // lognot().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/integer.h"
@@ -9,15 +9,15 @@
 
 // Implementation.
 
-#include "cl_I.h"
-#include "cl_DS.h"
-#include "cl_I_log.h"
+#include "integer/cl_I.h"
+#include "base/digitseq/cl_DS.h"
+#include "integer/bitwise/cl_I_log.h"
 
 namespace cln {
 
 const cl_I lognot (const cl_I& x)
     { if (fixnump(x)) // Fixnum -> ganz einfach:
-        { // bitweise als Fixnum zurck
+        { // bitweise als Fixnum zurück
           return cl_I_from_word(x.word ^ cl_combine(0,~(cl_uint)0));
         }
         else
