@@ -1,26 +1,22 @@
 // class cl_wht_from_integer_to_rcpointer.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_I_hashweak_rcpointer.h"
+#include "integer/hash/cl_I_hashweak_rcpointer.h"
 
 
 // Implementation.
 
-#include "cl_I.h"
-#include "cl_hash1weak.h"
+#include "integer/cl_I.h"
+#include "base/hash/cl_hash1weak.h"
 
 namespace cln {
 
 static void cl_weak_hashtable_from_integer_to_rcpointer_destructor (cl_heap* pointer)
 {
-#if (defined(__mips__) || defined(__mips64__)) && !defined(__GNUC__) // workaround SGI CC bug
-	(*(cl_heap_weak_hashtable_from_integer_to_rcpointer*)pointer).~cl_heap_weak_hashtable_1();
-#else
 	(*(cl_heap_weak_hashtable_from_integer_to_rcpointer*)pointer).~cl_heap_weak_hashtable_from_integer_to_rcpointer();
-#endif
 }
 
 cl_class cl_class_weak_hashtable_from_integer_to_rcpointer = {
@@ -30,7 +26,7 @@ cl_class cl_class_weak_hashtable_from_integer_to_rcpointer = {
 
 // These are not inline, because they tend to duplicate a lot of template code.
 
-cl_wht_from_integer_to_rcpointer::cl_wht_from_integer_to_rcpointer (cl_boolean (*maygc_htentry) (const cl_htentry_from_integer_to_rcpointer&))
+cl_wht_from_integer_to_rcpointer::cl_wht_from_integer_to_rcpointer (bool (*maygc_htentry) (const cl_htentry_from_integer_to_rcpointer&))
 {
 	var cl_heap_weak_hashtable_from_integer_to_rcpointer* ht = new cl_heap_weak_hashtable_from_integer_to_rcpointer (maygc_htentry);
 	ht->refcount = 1;
