@@ -1,7 +1,7 @@
 // cl_I (const char *) constructor.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/integer_class.h"
