@@ -1,10 +1,10 @@
 // cl_miller_rabin_test().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_IF.h"
+#include "numtheory/cl_IF.h"
 
 
 // Implementation.
