@@ -1,7 +1,7 @@
 // minusp().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/rational.h"
@@ -9,15 +9,15 @@
 
 // Implementation.
 
-#define minusp inline_minusp
-#include "cl_RA.h"
+#define minusp minusp_inline
+#include "rational/cl_RA.h"
 #undef minusp
 
 namespace cln {
 
-cl_boolean minusp (const cl_RA& x)
+bool CL_FLATTEN minusp (const cl_RA& x)
 {
-	return inline_minusp(x);
+	return minusp_inline(x);
 }
 
 }  // namespace cln
