@@ -1,7 +1,7 @@
 // recip().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/rational.h"
@@ -9,9 +9,9 @@
 
 // Implementation.
 
-#include "cl_RA.h"
-#include "cl_N.h"
-#include "cl_I.h"
+#include "cln/exception.h"
+#include "rational/cl_RA.h"
+#include "integer/cl_I.h"
 
 namespace cln {
 
@@ -23,7 +23,7 @@ const cl_RA recip (const cl_RA& r)
 // a>0 -> Ergebnis b/a (mit ggT(b,a)=1).
 // a<0 -> Ergebnis (- b)/(- a) (mit ggT(-b,-a)=1).
 	if (zerop(r))
-		cl_error_division_by_0();
+		throw division_by_0_exception();
 	var cl_I a;
 	var cl_I b;
 	RA_numden_I_I(r, a = , b = );
