@@ -3,13 +3,15 @@
 #include <cln/float.h>
 #include <cln/float_io.h>
 #include <cln/lfloat.h>
-#include "cl_LF.h"
+#include "float/lfloat/cl_LF.h"
 #include <cln/real.h>
 #include <cln/random.h>
 #include <cstdlib>
 #include <cstring>
 #include <cln/timing.h>
 using namespace cln;
+#include <iostream>
+using namespace std;
 
 int main (int argc, char * argv[])
 {
