@@ -1,12 +1,12 @@
 #include <cln/number.h>
 #include <cln/io.h>
 #include <cln/integer.h>
-#include "cl_DS.h"
-#include "cl_2DS.h"
+#include "base/digitseq/cl_DS.h"
+#include "base/digitseq/cl_2DS.h"
 #include <cln/random.h>
-#include "cl_random_impl.h"
-#include <stdlib.h>
-#include <string.h>
+#include "base/random/cl_random_impl.h"
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
 using namespace cln;
 
@@ -20,7 +20,7 @@ int main (int argc, char * argv[])
 	if (argc < 2)
 		exit(1);
 	uintL len = atoi(argv[1]);
-	SAVE_NUM_STACK;
+	CL_ALLOCA_STACK;
 	uintD* a_MSDptr;
 	uintD* a_LSDptr;
 	uintD* b_MSDptr;
